@@ -165,10 +165,12 @@ void WindowEffects::slideWindow(WId id, KWindowEffects::SlideFromLocation locati
     }
 }
 
+#if KWINDOWSYSTEM_VERSION <= QT_VERSION_CHECK(5, 61, 0)
 void WindowEffects::slideWindow(QWidget *widget, KWindowEffects::SlideFromLocation location)
 {
     slideWindow(widget->winId(), location, 0);
 }
+#endif
 
 QList<QSize> WindowEffects::windowSizes(const QList<WId> &ids)
 {
